Python API
==========

This is the documentation for the ``merlon`` Python package.

.. code-block:: python

   import merlon

   print("Merlon version:", merlon.version())
   print("Current package:", merlon.package.Package.current())


.. automodule:: merlon
   :members:

.. automodule:: merlon.package
   :members:

.. automodule:: merlon.package.manifest
   :members:

.. automodule:: merlon.package.distribute
   :members:

.. automodule:: merlon.package.init
   :members:

.. automodule:: merlon.package.registry
   :members:

.. automodule:: merlon.emulator
   :members:

.. automodule:: merlon.rom
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:
